@@ -15,15 +15,15 @@ def update_token_callback(bondid, rsp):
 class SelectCommand(BaseCommand):
     subcmd = "select"
     help = "Select a single Bond to interact with. If the token of this Bond is unlocked, it will be set. (The easiest way to unlock a token is with a power cycle)"
-    arguments = [
-        (
-            ["BONDID"],
-            {"nargs": "?", "help": "Bond ID to interact with in subsequent commands"},
-        ),
-        (["--none"], {"action": "store_true", "help": "clear selection"}),
-        (["--ip"], {"help": "specify Bond IP address"}),
-        (["--port"], {"help": "specify Bond HTTP port"}),
-    ]
+    arguments = {
+        "BONDID": {
+            "nargs": "?",
+            "help": "Bond ID to interact with in subsequent commands",
+        },
+        "--none": {"action": "store_true", "help": "clear selection"},
+        "--ip": {"help": "specify Bond IP address"},
+        "--port": {"help": "specify Bond HTTP port"},
+    }
 
     def run(self, args):
         if args.BONDID:
